@@ -1025,9 +1025,9 @@ NvS32 NV_API_CALL nv_get_event(
 
 void* NV_API_CALL nv_alloc_kernel_mapping(
     nv_state_t *nv,
-    NvU64 address,
-    NvU32 size,
-    void **private
+    NvU64       address,
+    NvU64       size,
+    void      **private
 )
 {
     struct nvidia_alloc *at;
@@ -1090,11 +1090,11 @@ found:
     return (void *)(virtual_address + offset);
 }
 
-NvS32 NV_API_CALL nv_free_kernel_mapping(
+RM_STATUS NV_API_CALL nv_free_kernel_mapping(
     nv_state_t *nv,
-    void *address,
-    void *private,
-    BOOL guest_mapping
+    void       *address,
+    void       *private,
+    NvBool      guest_mapping
 )
 {
     vm_offset_t virtual_address;
@@ -1110,6 +1110,26 @@ NvS32 NV_API_CALL nv_free_kernel_mapping(
     return RM_OK;
 }
 
+void* NV_API_CALL nv_alloc_user_mapping(
+    nv_state_t *nv,
+    NvU64       address,
+    NvU64       size,
+    NvU32       protect,
+    void      **priv_data
+)
+{
+    return (void *)(NvUPtr)address;
+}
+
+RM_STATUS NV_API_CALL nv_free_user_mapping(
+    nv_state_t *nv,
+    void       *address,
+    void       *priv_data
+)
+{
+    return RM_OK;
+}
+
 NvS32 nv_alloc_contig_pages(
     nv_state_t *nv,
     NvU32       count,
